==> clutternomore-1.1.2%2B1.21.5-fabric-sources.jar: dev/tazer/clutternomore/common/data/DataGenerator.java <==
package dev.tazer.clutternomore.common.data;

import com.google.gson.JsonArray;
import com.google.gson.JsonElement;
import com.google.gson.JsonObject;
import com.google.gson.JsonPrimitive;
import dev.tazer.clutternomore.ClutterNoMore;
import java.nio.file.Path;
import net.minecraft.class_2960;
import net.minecraft.class_3264;

import static dev.tazer.clutternomore.ClutterNoMore.pack;

public class DataGenerator {

    public static JsonArray verticalSlabsArray = new JsonArray();
    public static JsonArray stepsArray = new JsonArray();
    public static JsonArray woodenVerticalSlabsArray = new JsonArray();
    public static JsonArray woodenStepsArray = new JsonArray();
    public static JsonArray pickaxeMineableArray = new JsonArray();
    public static JsonArray shovelMineableArray = new JsonArray();

    public static void addToTag(String path, JsonArray array) {
        addToTag(ClutterNoMore.location(path), array);
    }

    public static void addToTag(class_2960 path, JsonArray array) {
        array.add(path.toString());
    }

    public static void generate() {
        blockAndItemTag("vertical_slabs", verticalSlabsArray);
        blockAndItemTag("wooden_vertical_slabs", woodenVerticalSlabsArray);
        blockAndItemTag("steps", stepsArray);
        blockAndItemTag("wooden_steps", woodenStepsArray);
        blockAndItemTag("minecraft","mineable/pickaxe", pickaxeMineableArray);
        blockAndItemTag("minecraft","mineable/shovel", shovelMineableArray);
    }

    private static void blockTag(String s, JsonArray verticalSlabTag) {
        blockTag(ClutterNoMore.MODID, s, verticalSlabTag);
    }

    private static void itemTag(String namespace, String s, JsonArray tagValues) {
        //? if >1.21 {
        var location = ClutterNoMore.location(namespace, "tags/item/" +s + ".json");
         //?} else {
        /*var location = ClutterNoMore.location(namespace, "tags/items/" +s + ".json");
        *///?}
        writeServerData(location, generateTagFile(tagValues));
    }

    private static void blockTag(String namespace, String s, JsonArray tagValues) {
        //? if >1.21 {
        var location = ClutterNoMore.location(namespace, "tags/block/" +s + ".json");
         //?} else {
        /*var location = ClutterNoMore.location(namespace, "tags/blocks/" +s + ".json");
        *///?}
        writeServerData(location, generateTagFile(tagValues));
    }

    private static void itemTag(String path, JsonArray verticalSlabTag) {
        itemTag(ClutterNoMore.MODID, path, verticalSlabTag);
    }

    private static void blockAndItemTag(String path, JsonArray verticalSlabTag) {
        blockTag(path, verticalSlabTag);
        itemTag(path, verticalSlabTag);
    }

    private static void blockAndItemTag(String namespace, String path, JsonArray verticalSlabTag) {
        blockTag(namespace, path, verticalSlabTag);
        itemTag(namespace, path, verticalSlabTag);
    }

    private static JsonObject generateTagFile(JsonArray tagValues) {
        JsonObject tag = new JsonObject();
        JsonArray values = new JsonArray();
        tagValues.forEach((value)->{
            var tagElement = new JsonObject();
            tagElement.add("id", value);
            tagElement.addProperty("required", false);
            values.add(tagElement);
        });
        tag.add("values", values);
        return tag;
    }

    public static void addLootTable(class_2960 block, class_2960 shape) {
        JsonObject lootTable = new JsonObject();
        lootTable.add("type", new JsonPrimitive("block"));
        JsonArray pools = new JsonArray();
        JsonObject pool = new JsonObject();
        pool.add("rolls", new JsonPrimitive(1));
        JsonArray entries = new JsonArray();
        JsonObject entry = new JsonObject();
        entry.add("type", new JsonPrimitive("loot_table"));
        entry.add("value", new JsonPrimitive(block.method_45138("blocks/").toString()));
        entries.add(entry);
        pool.add("entries", entries);
        pools.add(pool);
        lootTable.add("pools", pools);
        //? if >1.21 {
        var path = "loot_table";
         //?} else {
        /*var path = "loot_tables";
        *///?}
        writeServerData(("%s/blocks/%s.json".formatted(path, shape.method_12832())), lootTable);
    }

    public static void writeServerData(class_2960 fileName, JsonElement contents) {
        ClutterNoMore.RESOURCES.addJson(class_3264.field_14190, fileName, contents);
        if (ClutterNoMore.STARTUP_CONFIG.RUNTIME_DATA_GENERATION.value()) {
            Path data = pack.resolve("data/clutternomore");
            ClutterNoMore.writeFile(data.resolve(fileName.method_12832().substring(0, fileName.method_12832().lastIndexOf("/"))), data.resolve(fileName.method_12832()), contents.toString());
        }
    }

    public static void writeServerData(String fileName, JsonElement contents) {
        writeServerData(ClutterNoMore.location(fileName), contents);
    }
}

==> clutternomore-1.1.4%2B1.21.10-fabric-sources.jar: dev/tazer/clutternomore/common/data/DataGenerator.java <==
package dev.tazer.clutternomore.common.data;

import com.google.gson.JsonArray;
import com.google.gson.JsonElement;
import com.google.gson.JsonObject;
import com.google.gson.JsonPrimitive;
import dev.tazer.clutternomore.ClutterNoMore;
import java.nio.file.Path;
import net.minecraft.class_2960;
import net.minecraft.class_3264;

import static dev.tazer.clutternomore.ClutterNoMore.pack;

public class DataGenerator {

    public static JsonArray verticalSlabsArray = new JsonArray();
    public static JsonArray stepsArray = new JsonArray();
    public static JsonArray woodenVerticalSlabsArray = new JsonArray();
    public static JsonArray woodenStepsArray = new JsonArray();
    public static JsonArray pickaxeMineableArray = new JsonArray();
    public static JsonArray shovelMineableArray = new JsonArray();

    public static void addToTag(String path, JsonArray array) {
        addToTag(ClutterNoMore.location(path), array);
    }

    public static void addToTag(class_2960 path, JsonArray array) {
        array.add(path.toString());
    }

    public static void generate() {
        blockAndItemTag("vertical_slabs", verticalSlabsArray);
        blockAndItemTag("wooden_vertical_slabs", woodenVerticalSlabsArray);
        blockAndItemTag("steps", stepsArray);
        blockAndItemTag("wooden_steps", woodenStepsArray);
        blockAndItemTag("pickaxeable", pickaxeMineableArray);
        blockAndItemTag("shovelable", shovelMineableArray);
    }

    private static void blockTag(String s, JsonArray verticalSlabTag) {
        blockTag(ClutterNoMore.MODID, s, verticalSlabTag);
    }

    private static void itemTag(String namespace, String s, JsonArray tagValues) {
        //? if >1.21 {
        var location = ClutterNoMore.location(namespace, "tags/item/" +s + ".json");
         //?} else {
        /*var location = ClutterNoMore.location(namespace, "tags/items/" +s + ".json");
        *///?}
        writeServerData(location, generateTagFile(tagValues));
    }

    private static void blockTag(String namespace, String s, JsonArray tagValues) {
        //? if >1.21 {
        var location = ClutterNoMore.location(namespace, "tags/block/" +s + ".json");
         //?} else {
        /*var location = ClutterNoMore.location(namespace, "tags/blocks/" +s + ".json");
        *///?}
        writeServerData(location, generateTagFile(tagValues));
    }

    private static void itemTag(String path, JsonArray verticalSlabTag) {
        itemTag(ClutterNoMore.MODID, path, verticalSlabTag);
    }

    private static void blockAndItemTag(String path, JsonArray verticalSlabTag) {
        blockTag(path, verticalSlabTag);
        itemTag(path, verticalSlabTag);
    }

    private static void blockAndItemTag(String namespace, String path, JsonArray verticalSlabTag) {
        blockTag(namespace, path, verticalSlabTag);
        itemTag(namespace, path, verticalSlabTag);
    }

    private static JsonObject generateTagFile(JsonArray tagValues) {
        JsonObject tag = new JsonObject();
        JsonArray values = new JsonArray();
        tagValues.forEach((value)->{
            var tagElement = new JsonObject();
            tagElement.add("id", value);
            tagElement.addProperty("required", false);
            values.add(tagElement);
        });
        tag.add("values", values);
        return tag;
    }

    public static void addLootTable(class_2960 block, class_2960 shape) {
        JsonObject lootTable = new JsonObject();
        lootTable.add("type", new JsonPrimitive("block"));
        JsonArray pools = new JsonArray();
        JsonObject pool = new JsonObject();
        pool.add("rolls", new JsonPrimitive(1));
        JsonArray entries = new JsonArray();
        JsonObject entry = new JsonObject();
        entry.add("type", new JsonPrimitive("loot_table"));
        entry.add("value", new JsonPrimitive(block.method_45138("blocks/").toString()));
        entries.add(entry);
        pool.add("entries", entries);
        pools.add(pool);
        lootTable.add("pools", pools);
        //? if >1.21 {
        var path = "loot_table";
         //?} else {
        /*var path = "loot_tables";
        *///?}
        writeServerData(("%s/blocks/%s.json".formatted(path, shape.method_12832())), lootTable);
    }

    public static void writeServerData(class_2960 fileName, JsonElement contents) {
        ClutterNoMore.RESOURCES.addJson(class_3264.field_14190, fileName, contents);
        if (ClutterNoMore.STARTUP_CONFIG.RUNTIME_DATA_GENERATION.value()) {
            Path data = pack.resolve("data/"+fileName.method_12836());
            ClutterNoMore.writeFile(data.resolve(fileName.method_12832().substring(0, fileName.method_12832().lastIndexOf("/"))), data.resolve(fileName.method_12832()), contents.toString());
        }
    }

    public static void writeServerData(String fileName, JsonElement contents) {
        writeServerData(ClutterNoMore.location(fileName), contents);
    }
}
